; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
;

;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;
[Command]
name = "spikeroom"
command = ~D, DF, F, DF, D, DB, B, DB, D, DF, F, a
time = 40

[Command]
name = "slidecombo"
command = ~D, DB, B, DB, D, DF, F, y
time = 30

[Command]
name = "bigrock"
command = ~D, DF, F, D, DF, F, x
time = 30

[Command]
name = "bigrock2"
command = ~D, DF, F, D, DF, F, y
time = 30

;-| Special Motions |------------------------------------------------------
[Command]
name = "shorback_a"
command = ~B, D, DB, a

[Command]
name = "shorfor_a"
command = ~F, D, DF, a

[Command]
name = "fdf_a"
command = ~F, D, DF, a

[Command]
name = "df_x"
command = ~D, DF, F, x

[Command]
name = "df_y"
command = ~D, DF, F, y

[Command]
name = "bf_a"
command = ~B, F, a

[Command]
name = "bf_x"
command = ~B, F, x

[Command]
name = "bf_y"
command = ~B, F, y

[Command]
name = "fb_y"
command = ~F, B, y

[Command]
name = "bdf_a"
command = ~B, DB, D, DF, F, a
time = 25

[Command]
name = "fdb_a"
command = ~F, DF, D, DB, B, a
time = 25

[Command]
name = "grab"
command = x+y

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
;Hypers
;---------------------------------------------------------------------------
;Big Rock
[State -1, Big Rock]
type = ChangeState
value = 3000
triggerall = Command = "bigrock" || Command = "bigrock2"
triggerall = power >= 1000
trigger1 = Statetype != A
trigger1 = ctrl
trigger1 = NumProj = 0

;---------------------------------------------------------------------------
;Slide Combo
[State -1, Slide Combo]
type = ChangeState
value = 3005
triggerall = Command = "slidecombo"
triggerall = power >= 2000
trigger1 = Statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Spike Room
[State -1, Spike Room]
type = ChangeState
value = 3010
triggerall = Command = "spikeroom"
triggerall = power >= 3000
trigger1 = Statetype != A
trigger1 = ctrl

;===========================================================================
;---------------------------------------------------------------------------
;Specials
;---------------------------------------------------------------------------
;Ice Rocks I
[State -1, Ice Rocks I]
type = ChangeState
value = 700
trigger1 = command = "df_x"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Ice Rocks II
[State -1, Ice Rocks II]
type = ChangeState
value = 705
trigger1 = command = "df_y"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Flying Cut
[State -1, Flying Cut]
type = ChangeState
value = 710
trigger1 = command = "bf_x"
trigger1 = ctrl

;---------------------------------------------------------------------------
;Flying Cut Air
[State -1, Flying Cut Air]
type = ChangeState
value = 715
trigger1 = command = "bf_y"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Flying Cut Down
[State -1, Flying Cut Down]
type = ChangeState
value = 725
trigger1 = command = "bf_y"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Flying Cut Vertical
[State -1, Flying Cut Vertical]
type = ChangeState
value = 745
trigger1 = command = "fdf_a"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Flying Cut Down Back
[State -1, Flying Cut Down Back]
type = ChangeState
value = 765
trigger1 = command = "fb_y"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Standing Spikes
[State -1, Standing Spikes]
type = ChangeState
value = 780
trigger1 = command = "bdf_a"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Standing Spikes Back
[State -1, Standing Spikes Back]
type = ChangeState
value = 785
trigger1 = command = "fdb_a"
trigger1 = statetype != A
trigger1 = ctrl

;===========================================================================
;---------------------------------------------------------------------------
;Crouching Claw Attack
[State -1, Crouching Claw Attack]
type = ChangeState
value = 400
triggerall = command = "holddown"
triggerall = command = "x"
trigger1 = ctrl
trigger1 = statetype = C

;---------------------------------------------------------------------------
;Crouching Kick Attack
[State -1, Crouching Kick Attack]
type = ChangeState
value = 410
triggerall = command = "holddown"
triggerall = command = "b"
trigger1 = ctrl
trigger1 = statetype = C

;---------------------------------------------------------------------------
;Crouching Thrust Attack
[State -1, Crouching Thrust Attack]
type = ChangeState
value = 420
triggerall = command = "holddown"
triggerall = command = "y"
trigger1 = ctrl
trigger1 = statetype = C

;---------------------------------------------------------------------------
;Crouching Punch Attack
[State -1, Crouching Punch Attack]
type = ChangeState
value = 430
triggerall = command = "holddown"
triggerall = command = "a"
trigger1 = ctrl
trigger1 = statetype = C

;---------------------------------------------------------------------------
;Air Claw Attack
[State -1, Air Claw Attack]
type = ChangeState
value = 600
triggerall = command = "x"
trigger1 = ctrl
trigger1 = StateType = A

;---------------------------------------------------------------------------
;Air Kick Attack
[State -1, Air Kick Attack]
type = ChangeState
value = 610
triggerall = command = "b"
trigger1 = ctrl
trigger1 = StateType = A

;---------------------------------------------------------------------------
;Air Thrust Attack
[State -1, Air Thrust Attack]
type = ChangeState
value = 620
triggerall = command = "y"
trigger1 = ctrl
trigger1 = StateType = A

;---------------------------------------------------------------------------
;Air Punch Attack
[State -1, Air Punch Attack]
type = ChangeState
value = 630
triggerall = command = "a"
trigger1 = ctrl
trigger1 = StateType = A

;---------------------------------------------------------------------------
;Small Claw Attack
[State -1, Small Claw Attack]
type = ChangeState
value = 200
triggerall = command = "x"
trigger1 = ctrl
trigger1 = StateType != A
trigger2 = stateno = 230 && movehit = 1

;---------------------------------------------------------------------------
;Claw Thrust Attack
[State -1, Claw Thrust Attack]
type = ChangeState
value = 210
triggerall = command = "y"
trigger1 = ctrl
trigger1 = StateType != A

;---------------------------------------------------------------------------
;Kick Attack
[State -1, Kick Attack]
type = ChangeState
value = 220
triggerall = command = "b"
trigger1 = ctrl
trigger1 = StateType != A

;---------------------------------------------------------------------------
;Punch Attack
[State -1, Punch Attack]
type = ChangeState
value = 230
triggerall = command = "a"
trigger1 = ctrl
trigger1 = StateType != A
trigger2 = stateno = 200 && movehit = 1

;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

